@@ -16,6 +16,7 @@
 #include "electrical_current_p.h"
 #include "electrical_resistance_p.h"
 #include "energy_p.h"
+#include "weight_per_area_p.h"
 #include "force_p.h"
 #include "frequency_p.h"
 #include "fuel_efficiency_p.h"
@@ -29,6 +30,7 @@
 #include "thermal_flux_p.h"
 #include "thermal_generation_p.h"
 #include "timeunit_p.h"
+#include "unit.h"
 #include "velocity_p.h"
 #include "voltage_p.h"
 #include "volume_p.h"
@@ -42,50 +44,32 @@ class ConverterPrivate : public QSharedData
 public:
     ConverterPrivate()
     {
-        m_categories[LengthCategory] = Length();
-        m_categories[AreaCategory] = Area();
-        m_categories[VolumeCategory] = Volume();
-        m_categories[TemperatureCategory] = Temperature();
-        m_categories[VelocityCategory] = Velocity();
-        m_categories[MassCategory] = Mass();
-        m_categories[PressureCategory] = Pressure();
-        m_categories[EnergyCategory] = Energy();
-        m_categories[CurrencyCategory] = Currency();
-        m_categories[PowerCategory] = Power();
-        m_categories[TimeCategory] = Time();
-        m_categories[FuelEfficiencyCategory] = FuelEfficiency();
-        m_categories[DensityCategory] = Density();
-        m_categories[AccelerationCategory] = Acceleration();
-        m_categories[ForceCategory] = Force();
-        m_categories[AngleCategory] = Angle();
-        m_categories[FrequencyCategory] = Frequency();
-        m_categories[ThermalConductivityCategory] = ThermalConductivity();
-        m_categories[ThermalFluxCategory] = ThermalFlux();
-        m_categories[ThermalGenerationCategory] = ThermalGeneration();
-        m_categories[VoltageCategory] = Voltage();
-        m_categories[ElectricalCurrentCategory] = ElectricalCurrent();
-        m_categories[ElectricalResistanceCategory] = ElectricalResistance();
-        m_categories[PermeabilityCategory] = Permeability();
-        m_categories[BinaryDataCategory] = BinaryData();
-    }
-
-    virtual ~ConverterPrivate()
-    {
-    }
-
-    ConverterPrivate *clone()
-    {
-        return new ConverterPrivate(*this);
-    }
-
-    bool operator==(const ConverterPrivate &other) const
-    {
-        return (m_categories == other.m_categories);
-    }
-
-    bool operator!=(const ConverterPrivate &other) const
-    {
-        return !(*this == other);
+        m_categories[LengthCategory] = Length::makeCategory();
+        m_categories[AreaCategory] = Area::makeCategory();
+        m_categories[VolumeCategory] = Volume::makeCategory();
+        m_categories[TemperatureCategory] = Temperature::makeCategory();
+        m_categories[VelocityCategory] = Velocity::makeCategory();
+        m_categories[MassCategory] = Mass::makeCategory();
+        m_categories[PressureCategory] = Pressure::makeCategory();
+        m_categories[EnergyCategory] = Energy::makeCategory();
+        m_categories[CurrencyCategory] = Currency::makeCategory();
+        m_categories[PowerCategory] = Power::makeCategory();
+        m_categories[TimeCategory] = Time::makeCategory();
+        m_categories[FuelEfficiencyCategory] = FuelEfficiency::makeCategory();
+        m_categories[DensityCategory] = Density::makeCategory();
+        m_categories[WeightPerAreaCategory] = WeightPerArea::makeCategory();
+        m_categories[AccelerationCategory] = Acceleration::makeCategory();
+        m_categories[ForceCategory] = Force::makeCategory();
+        m_categories[AngleCategory] = Angle::makeCategory();
+        m_categories[FrequencyCategory] = Frequency::makeCategory();
+        m_categories[ThermalConductivityCategory] = ThermalConductivity::makeCategory();
+        m_categories[ThermalFluxCategory] = ThermalFlux::makeCategory();
+        m_categories[ThermalGenerationCategory] = ThermalGeneration::makeCategory();
+        m_categories[VoltageCategory] = Voltage::makeCategory();
+        m_categories[ElectricalCurrentCategory] = ElectricalCurrent::makeCategory();
+        m_categories[ElectricalResistanceCategory] = ElectricalResistance::makeCategory();
+        m_categories[PermeabilityCategory] = Permeability::makeCategory();
+        m_categories[BinaryDataCategory] = BinaryData::makeCategory();
     }
 
     QMap<CategoryId, UnitCategory> m_categories;
@@ -123,22 +107,10 @@ Converter &Converter::operator=(const Converter &other)
     return *this;
 }
 
-bool Converter::operator==(const Converter &other) const
+Converter &Converter::operator=(Converter &&other)
 {
-    if (d && other.d) {
-        return (*d == *other.d);
-    } else {
-        return (d == other.d);
-    }
-}
-
-bool Converter::operator!=(const Converter &other) const
-{
-    if (d && other.d) {
-        return (*d != *other.d);
-    } else {
-        return (d != other.d);
-    }
+    d.swap(other.d);
+    return *this;
 }
 
 Value Converter::convert(const Value &value, const QString &toUnit) const
